@@ -1,7 +1,7 @@
 BarChart <-
 function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"), 
 
-         col.fill=NULL, col.stroke="black",
+         col.fill=NULL, col.stroke=getOption("col.stroke.bar"),
          col.bg=getOption("col.bg"),
          col.grid=getOption("col.grid"),
          random.col=FALSE,
@@ -27,58 +27,43 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   else
     colors <- match.arg(colors)
 
+  if (missing(col.stroke))  # default black border unless dark bg
+    if (sum(col2rgb(col.bg))/3 > 80) col.stroke <- "black"
+
   x.name <- deparse(substitute(x))
   options(xname = x.name)
 
-  is.df <- FALSE  # is data frame
+  df.name <- deparse(substitute(data))
+  options(dname = df.name)
 
-  if (missing(x)) {
-    x.name <- ""  # in case x is missing, i.e., data frame mydata
-    is.df <- TRUE
-    data <- eval(substitute(mydata))
-  }
 
-  else if ( (!grepl(":", x.name) && !grepl(",", x.name)) ) {  # not a var list
-    if (exists(x.name, where=1)) if (is.data.frame(x)) {
+# -----------------------------------------------------------
+# establish if a data frame, if not then identify variable(s)
+
+  x.call <- NULL
+
+  if (!missing(x)) {
+    if (!exists(x.name, where=.GlobalEnv)) {  # x not in global env, in df
+      .nodf(df.name)  # check to see if data frame container exists 
+      .xcheck(x.name, df.name, data)  # see if var in df, vars lists not checked
+      vars.list <- as.list(seq_along(data))
+      names(vars.list) <- names(data)
+      x.col <- eval(substitute(x), envir=vars.list)  # col num of each var
+      if (length(x.col) > 1) data <- data[, x.col]  # x is a vars list
+      if (length(x.col) == 1) x.call <- eval(substitute(data$x))  # x is 1 var
+    }
+    else { # x is in the global environment (vector or data frame)
+      if (is.data.frame(x))  # x a data frame
         data <- x
-        is.df <- TRUE
+      else {  # x a vector in global
+        x.call <- x
+        if (is.function(x.call)) x.call <- eval(substitute(data$x))
+      }
     }
   }
 
-  # proceed here only if x.name is a var list
-  else if (grepl(":", x.name) || grepl(",", x.name) ) {
-    all.vars <- as.list(seq_along(data))
-    names(all.vars) <- names(data)
-    x.col <- eval(substitute(x), envir=all.vars, enclos=parent.frame())
-    data <- data[, x.col]  # create subset data frame
-    is.df <- TRUE
-  }
 
-  if (!is.df) {
-
-    dname <- deparse(substitute(data))
-    options(dname = dname)
-
-    # get conditions and check for data existing
-    xs <- .xstatus(x.name, dname, quiet)
-    is.frml <- xs$ifr
-    in.global <- xs$ig 
-
-    # warn user that old formula mode no longer works
-    if (is.frml) {
-      cat("\n"); stop(call.=FALSE, "\n","------\n",
-          "Instead, of 'Y ~ X', now use the by option, 'Y, by=X' \n\n")
-    }
-
-    # see if the variable exists in data frame, if x not in Global Env 
-    if (!in.global) .xcheck(x.name, dname, data)
-
-
-    if (!in.global) x.call <- eval(substitute(data$x))
-    else {  # vars that are function names get assigned to global
-      x.call <- x
-      if (is.function(x.call)) x.call <- eval(substitute(data$x))
-    }
+  if (!is.null(x.call)) {  # x is a single var, not a data frame
 
     # evaluate by
     if (!missing(by)) {
@@ -88,19 +73,19 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       options(yname = y.name)
 
       # see if y exists from a function call
-      # indicate a function call with sys.frame returns larger than 1 
+      # indicate a function call with sys.nframe returns larger than 1 
       if (exists(y.name, where=parent.frame(n=1)) && sys.nframe() > 1) 
         in.call <- TRUE else in.call <- FALSE
 
       # get conditions and check for data existing
       if (!in.call) {
-        xs <- .xstatus(y.name, dname, quiet)
+        xs <- .xstatus(y.name, df.name, quiet)
         in.global <- xs$ig 
       }
       else in.global <- FALSE
 
       # see if var exists in data frame, if x not in Global Env or function call 
-      if (!in.global && !in.call) .xcheck(y.name, dname, data)
+      if (!in.global && !in.call) .xcheck(y.name, df.name, data)
 
       if (!in.global) y.call <- eval(substitute(data$by))
       else {  # vars that are function names get assigned to global
@@ -109,47 +94,37 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       }
 
     }
-    else y.call <- NULL
+    else
+      y.call <- NULL
 
 
-  # evaluate count.levels
-  #---------------------
-  if (!missing(count.levels)) {
+    # evaluate count.levels
+    #---------------------
+    if (!missing(count.levels)) {
 
-    # get actual variable name before potential call of data$x
-    count.levels.name <- deparse(substitute(count.levels)) 
-    options(count.levelsname = count.levels.name)
+      # get actual variable name before potential call of data$x
+      count.levels.name <- deparse(substitute(count.levels)) 
+      options(count.levelsname = count.levels.name)
 
-    # get conditions and check for data existing
-    xs <- .xstatus(count.levels.name, dname, quiet)
-    in.global <- xs$ig 
+      # get conditions and check for data existing
+      xs <- .xstatus(count.levels.name, df.name, quiet)
+      in.global <- xs$ig 
 
-    # see if var exists in data frame, if x not in Global Env or function call 
-    if (!missing(x) && !in.global)
-      .xcheck(count.levels.name, dname, data)
+      # see if var exists in data frame, if x not in Global Env or function call 
+      if (!missing(x) && !in.global)
+        .xcheck(count.levels.name, df.name, data)
 
-    if (!in.global) count.levels.call <- eval(substitute(data$count.levels))
-    else {  # vars that are function names get assigned to global
-      count.levels.call <- count.levels
-      if (is.function(count.levels.call)) 
-        count.levels.call <- eval(substitute(data$count.levels))
+      if (!in.global) count.levels.call <- eval(substitute(data$count.levels))
+      else {  # vars that are function names get assigned to global
+        count.levels.call <- count.levels
+        if (is.function(count.levels.call)) 
+          count.levels.call <- eval(substitute(data$count.levels))
+      }
     }
-  }
-  else
-   count.levels.call <- NULL
+    else
+      count.levels.call <- NULL
 
-  }  # x not data frame
 
-  if (is.df) bc.data.frame(data, n.cat,
-         col.fill, col.stroke, col.bg, col.grid, random.col, colors,
-         horiz, over.grid, addtop, gap, prop, xlab, ylab, main,
-         cex.axis, col.axis, col.ticks, beside, col.low, col.hi,
-         count.levels,
-         legend.title, legend.loc, legend.labels, legend.horiz, quiet,
-         pdf.width, pdf.height, ...)
-
-  else {
-  
     if (length(unique(na.omit(x.call))) == 1) { 
       cat("\n"); stop(call.=FALSE, "\n","------\n",
         "There is only one unique value for the values of ", x.name,
@@ -158,6 +133,9 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         " unique value\n\n")
     }
 
+# ---------------
+# do the analysis
+
     .opendev(pdf.file, pdf.width, pdf.height)
 
     orig.params <- par(no.readonly=TRUE)
@@ -172,11 +150,20 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
     if (!is.null(pdf.file)) {
       dev.off()
-      .showfile(pdf.file, "barchart")
+      if (!quiet) .showfile(pdf.file, "barchart")
     }
 
     invisible(bc)
   }
 
+  else
+    bc.data.frame(data, n.cat,
+      col.fill, col.stroke, col.bg, col.grid, random.col, colors,
+      horiz, over.grid, addtop, gap, prop, xlab, ylab, main,
+      cex.axis, col.axis, col.ticks, beside, col.low, col.hi,
+      count.levels,
+      legend.title, legend.loc, legend.labels, legend.horiz, quiet,
+      pdf.width, pdf.height, ...)
+
 }
 
